<?php
/**
 * Artix functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Artix
 */

if ( ! function_exists( 'artix_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function artix_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Artix, use a find and replace
		 * to change 'artix' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'artix', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'artix' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'artix_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'artix_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function artix_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'artix_content_width', 640 );
}
add_action( 'after_setup_theme', 'artix_content_width', 0 );

/**
 * Artix Custom Header
 */

function artix_custom_header_setup() {
    $args = array(
        'default-image'      => get_template_directory_uri() . '/img/custom-header.jpg',
        'default-text-color' => 'fff',
        'width'              => 2000,
        'height'             => 1200,
        'flex-width'         => true,
        'flex-height'        => true,
        'header-text'        => false,
    );
    add_theme_support( 'custom-header', $args );
}
add_action( 'after_setup_theme', 'artix_custom_header_setup' );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function artix_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'artix' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'artix' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	//Footer 1
	register_sidebar( array(
		'name' => esc_html__( 'Footer 1', 'artix' ),
		'id'   => 'footer-one',
		'description' => esc_html__( 'Widgets to show in first footer area' , 'artix'),
		'before_widget' => '<div id="%1$s" class="footer-widget %2$s clr">',
		'after_widget' => '</div>',
		'before_title' => '<h2 class="widget-title">',
		'after_widget' => '</h2>',
	) );

	//Footer 2
	register_sidebar( array(
		'name' => esc_html__( 'Footer 2', 'artix' ),
		'id'   => 'footer-two',
		'description' => esc_html__( 'Widgets to show in 2nd footer area' , 'artix'),
		'before_widget' => '<div id="%1$s" class="footer-widget %2$s clr">',
		'after_widget' => '</div>',
		'before_title' => '<h2 class="widget-title">',
		'after_widget' => '</h2>',
	) );

	//Footer 3
	register_sidebar( array(
		'name' => esc_html__( 'Footer 3', 'artix' ),
		'id'   => 'footer-three',
		'description' => esc_html__( 'Widgets to show in 3rd footer area' , 'artix'),
		'before_widget' => '<div id="%1$s" class="footer-widget %2$s clr">',
		'after_widget' => '</div>',
		'before_title' => '<h2 class="widget-title">',
		'after_widget' => '</h2>',
	) );

	//Footer 4
	register_sidebar( array(
		'name' => esc_html__( 'Footer 4', 'artix' ),
		'id'   => 'footer-four',
		'description' => esc_html__( 'Widgets to show in 4th footer area' , 'artix'),
		'before_widget' => '<div id="%1$s" class="footer-widget %2$s clr">',
		'after_widget' => '</div>',
		'before_title' => '<h2 class="widget-title">',
		'after_widget' => '</h2>',
	) );
}
add_action( 'widgets_init', 'artix_widgets_init' );


/**
 * Apply theme's stylesheet to the visual editor.
 *
 * @uses add_editor_style() Links a stylesheet to visual editor
 * @uses get_stylesheet_uri() Returns URI of theme stylesheet
 */
function cd_add_editor_styles() {
 add_editor_style( get_stylesheet_uri() );
}
add_action( 'init', 'cd_add_editor_styles' );






/**
 * Enqueue scripts and styles.
 */
require get_template_directory() . '/inc/enqueue-scripts.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';
